* ============================================================
* 908GP32 HEADER FILE
* Defines register and bit values for assembler
* Last modified: 10/25/99
* By: JJ
* ============================================================
*************************************************************
* PORT I/O
*************************************************************
PORTA           EQU     $00             ;I/O PORT A
PORTB           EQU     $01             ;I/O PORT B
PORTC           EQU     $02             ;I/O PORT C
PORTD           EQU     $03             ;I/O PORT D
PORTE           EQU     $08             ;I/O PORT E

P7              EQU     7               ;BIT #7 OF PORT
P6              EQU     6
P5              EQU     5
P4              EQU     4
P3              EQU     3
P2              EQU     2
P1              EQU     1
P0              EQU     0
P7.             EQU     $80             ;BIT POSITION P7
P6.             EQU     $40
P5.             EQU     $20
P4.             EQU     $10
P3.             EQU     $08
P2.             EQU     $04
P1.             EQU     $02
P0.             EQU     $01

* DATA DIRECTION REGISTERS A-E
DDRA            EQU     $04             ;PORT A DATA DIRECTION REGISTER
DDRB            EQU     $05             ;PORT B DATA DIRECTION REGISTER
DDRC            EQU     $06             ;PORT C DATA DIRECTION REGISTER
DDRD            EQU     $07             ;PORT D DATA DIRECTION REGISTER
DDRE            EQU     $0C             ;PORT E DATA DIRECTION REGISTER

* PORT PULLUP ENABLE REGISTERS A,C,D
PTAPUE		EQU	$0D		;PORT A PULLUP ENABLE REGISTER
PTCPUE		EQU	$0E		;PORT C PULLUP ENABLE REGISTER
PTDPUE		EQU	$0F		;PORT D PULLUP ENABLE REGISTER

*************************************************************
* CONFIG 1 REGISTER
*************************************************************
CONFIG1         EQU     $1F           	;CONFIG1 REGISTER
COPRS           EQU     7
LVISTOP         EQU     6
LVIRSTD         EQU     5
LVIPWRD         EQU     4
LVI5OR3         EQU     3
SSREC           EQU     2
STOP            EQU     1
COPD            EQU     0
COPRS.          EQU     $80
LVISTOP.        EQU     $40
LVIRSTD.        EQU     $20
LVIPWRD.        EQU     $10
LVI5OR3.        EQU     $08
SSREC.          EQU     $04
STOP.           EQU     $02
COPD.           EQU     $01

*************************************************************
* CONFIG 2 REGISTER
*************************************************************
CONFIG2         EQU     $1E           	;CONFIG2 REGISTER
*               EQU     7
*               EQU     6
*               EQU     5
SEC             EQU     4               ;Security
*               EQU     3
*               EQU     2
OSCSTOPEN       EQU     1               ;Enable Oscillator in STOP
SCIBDSRC        EQU     0               ;SCI baud rate clock sourc
*  .            EQU     $80             ;BIT POSITION 7
*  .            EQU     $40
*  .            EQU     $20
SEC.            EQU     $10
*  .            EQU     $08
*  .            EQU     $04
OSCSTOPEN.      EQU     $02
SCIBDSRC.       EQU     $01

*************************************************************
* SIM - System Integration Module
*************************************************************
SRSR      	EQU     $FE01     	;SIM Reset status register
POR             EQU     7
PIN             EQU     6
COP             EQU     5
ILOP            EQU     4
ILAD            EQU     3
*               EQU     2
LVI	        EQU     1
*               EQU     0
POR.            EQU     $80
PIN.            EQU     $40
COP.            EQU     $20
ILOP.           EQU     $10
ILAD.           EQU     $08
*  .            EQU     $04
LVI.      	EQU     $02
*  .       	EQU     $01

*************************************************************
* FLASH CONTROL REGISTER
*************************************************************
FLCR            EQU     $FE08           ;FLASH CONTROL REGISTER
FDIV1           EQU     7
FDIV0           EQU     6
BLK1            EQU     5
BLK0            EQU     4
HVEN            EQU     3
VERF            EQU     2               ;FOR 908GP20 ONLY
MARG            EQU     2               ;FOR 908XL36 ONLY
ERASE           EQU     1
PGM             EQU     0
FDIV1.          EQU     $80
FDIV0.          EQU     $40
BLK1.           EQU     $20
BLK0.           EQU     $10
HVEN.           EQU     $08
VERF.           EQU     $04
MARG.           EQU     $04
ERASE.          EQU     $02
PGM.            EQU     $01

*************************************************************
*  BLOCK PROTECTION REGISTER
*************************************************************
FLBPR           EQU     $FF80           ;FLASH BLOCK PROTECTION
*               EQU     7
*               EQU     6
*               EQU     5
*               EQU     4
BPR3            EQU     3
BPR2            EQU     2
BPR1            EQU     1
BPR0            EQU     0
*   .           EQU     $80
*   .           EQU     $40
*   .           EQU     $20
*   .           EQU     $10
BPR3.           EQU     $08
BPR2.           EQU     $04
BPR1.           EQU     $02
BPR0.           EQU     $01

*************************************************************
* PLL - Phase-locked-loop
*************************************************************
PCTL            EQU     $36           	;PLL Control Register
PBWC            EQU     $37           	;PLL Bandwidth Control Register
PMSH            EQU     $38           	;PLL Multiplier Select Register High
PMSL            EQU     $39           	;PLL Multiplier Select Register Low
PMRS            EQU     $3A           	;PLL VCO Range Select Register
PMDS            EQU     $3B           	;PLL Reference Divider Select Register

* PBWC bits
AUTO            EQU     7
LOCK            EQU     6
ACQ		EQU	5

* PCTL bits
PLLIE		EQU	7
PLLF		EQU	6
PLLON           EQU     5
BCS             EQU     4
PLLIE.		EQU	$80
PLLF.		EQU	$40
PLLON.		EQU	$20
BCS.		EQU	$10

*************************************************************
* SCI - Serial Communications Interface
*************************************************************
SCC1            EQU     $13             ;SCI CONTROL REGISTER 1
LOOPS           EQU     7               ;BIT #7
ENSCI           EQU     6
TXINV           EQU     5
M               EQU     4
WAKE            EQU     3
ILTY            EQU     2
PEN             EQU     1
PTY             EQU     0
LOOPS.          EQU     $80             ;BIT POSITION 7
ENSCI.          EQU     $40
TXINV.          EQU     $20
M.              EQU     $10
WAKE.           EQU     $08
ILTY.           EQU     $04
PEN.            EQU     $02
PTY.            EQU     $01

SCC2            EQU     $14             ;SCI CONTROL REGISTER 2
TIE             EQU     7               ;Transmit interrupt enable
TCIE            EQU     6
RIE             EQU     5
ILIE            EQU     4               ;Idle line interrupt enable
TE              EQU     3               ;Transmit enable
RE              EQU     2               ;Receive enable
RWU             EQU     1               ;Receiver wakeup enable
SBK             EQU     0               ;Send break
TIE.            EQU     $80
TCIE.           EQU     $40
RIE.            EQU     $20
ILIE.           EQU     $10
TE.             EQU     $08
RE.             EQU     $04
RWU.            EQU     $02
SBK.            EQU     $01

SCC3            EQU     $15             ;SCI CONTROL REGISTER 3
R8              EQU     7               ;Bit 8 receive (for 9-bit characters)
T8              EQU     6               ;Bit 8 transmit
DMARE           EQU     5
DMATE           EQU     4
ORIE            EQU     3
NEIE            EQU     2
FEIE            EQU     1
PEIE            EQU     0
R8.             EQU     $80
T8.             EQU     $40
DMARE.          EQU     $20
DMATE.          EQU     $10
ORIE.           EQU     $08
NEIE.           EQU     $04
FEIE.           EQU     $02
PEIE.           EQU     $01

SCS1            EQU     $16             ;SCI STATUS REGISTER 1
SCTE            EQU     7               ;BIT #7
TC              EQU     6
SCRF            EQU     5
IDLE            EQU     4
OR              EQU     3
NF              EQU     2
FE              EQU     1
PE              EQU     0
SCTE.           EQU     $80             ;BIT POSITION 7
TC.             EQU     $40
SCRF.           EQU     $20
IDLE.           EQU     $10
OR.             EQU     $08
NF.             EQU     $04
FE.             EQU     $02
PE.             EQU     $01

SCS2            EQU     $17             ;SCI STATUS REGISTER 2
*               EQU     7               ;BIT #7
*               EQU     6
*               EQU     5
*               EQU     4
*               EQU     3
*               EQU     2
BKF             EQU     1
RPF             EQU     0
*.              EQU     $80             ;BIT POSITION 7
*.              EQU     $40
*.              EQU     $20
*.              EQU     $10
*.              EQU     $08
*.              EQU     $04
BKF.            EQU     $02
RPF.            EQU     $01

SCDR            EQU     $18             ;SCI Data
RDR             EQU     $18             ;SCI Receive Data (same as SCDR)
TDR             EQU     $18             ;SCI Transmit Data (same as SCDR)

SCBR            EQU     $19             ;SCI BAUD RATE REGISTER
*               EQU     7
*               EQU     6
SCP1            EQU     5               ;SCI prescaler sel bit 1 00=clk/1, 01=clk/3
SCP0            EQU     4               ;SCI prescaler sel bit 0 10=clk/4, 11=clk/13
RES             EQU     3
SCR2            EQU     2               ;SCI baud rate sel bit 2 000=/1...111=/128
SCR1            EQU     1               ;SCI baud rate sel, bit 1
SCR0            EQU     0               ;SCI baud rate sel, bit 0
* .             EQU     $80
* .             EQU     $40
SCP1.           EQU     $20
SCP0.           EQU     $10
RES.            EQU     $08
SCR2.           EQU     $04
SCR1.           EQU     $02
SCR0.           EQU     $01

SCTIE     	EQU     7
SCRIE     	EQU     5

*************************************************************
* SPI - Serial Peripheral Interface
*************************************************************
SPCR      	EQU	$10		;SPI Control
SPSCR     	EQU     $11       	;SPI Status and Control
SPDR      	EQU     $12       	;SPI Data

* SPCR bits
SPRIE     	EQU  	7
DMAS      	EQU     6
SPMSTR    	EQU     5
CPOL      	EQU     4
CPHA      	EQU     3
SPWOM     	EQU     2
SPE       	EQU     1
SPTIE     	EQU     0

* SPSCR bits
SPRF      	EQU     7
ERRIE     	EQU     6
OVRF      	EQU     5
MODF      	EQU     4
SPTE      	EQU     3
MODFEN    	EQU     2
SPR1      	EQU     1
SPR0      	EQU     0

* I/O lines shared with PORT D
SPSCK		EQU	3
MOSI		EQU	2
MISO		EQU	1
SS		EQU	0


*************************************************************
* TIM - Timer Interface Module
*************************************************************
* Timer 1
T1SC      	EQU     $20            	;Timer 1 status and control
T1CNTH		EQU	$21		;Timer 1 counter register high byte
T1CNTL		EQU	$22		;Timer 1 counter register low byte
T1MODH    	EQU     $23            	;Timer 1 counter modulo high byte
T1MODL    	EQU     $24            	;Timer 1 counter modulo low byte
T1SC0     	EQU     $25            	;Timer 1 channel 0 status and control
T1CH0H    	EQU     $26            	;Timer 1 channel 0 high byte
T1CH0L  	EQU     $27            	;Timer 1 channel 0 low byte
T1SC1		EQU	$28            	;Timer 1 channel 1 status and control
T1CH1H		EQU	$29		;Timer 1 channel 1 high byte
T1CH1L		EQU	$2A		;Timer 1 channel 1 low byte

* Timer 2
T2SC      	EQU     $2B            	;Timer 2 status and control
T2CNTH		EQU	$2C		;Timer 2 counter register high byte
T2CNTL		EQU	$2D		;Timer 2 counter register low byte
T2MODH    	EQU     $2E            	;Timer 2 counter modulo high byte
T2MODL    	EQU     $2F            	;Timer 2 counter modulo low byte
T2SC0     	EQU     $30            	;Timer 2 channel 0 status and control
T2CH0H    	EQU     $31            	;Timer 2 channel 0 high byte
T2CH0L  	EQU     $32            	;Timer 2 channel 0 low byte
T2SC1		EQU	$33            	;Timer 2 channel 1 status and control
T2CH1H		EQU	$34		;Timer 2 channel 1 high byte
T2CH1L		EQU	$35		;Timer 2 channel 1 low byte

* TxSC bits, applies to either T1SC or T2SC
TOF		EQU	7		;Timer overflow bit in TxSC
TOIE		EQU	6		;Timer overflow interrupt enable
TSTOP     	EQU     5            	;Timer stop bit in TxSC
TRST      	EQU     4            	;Timer reset bit in TxSC

* TxSCx bits, applies to T1CH0||T1CH1||T2CH0||T2CH1
CHF       	EQU     7            	;Flag; any channel
CHIE      	EQU     6            	;Interrupt enable; any channel
MSB       	EQU     5            	;Mode select B; channel 0 or 2
MSA       	EQU     4            	;Mode select A; any channel
ELSB      	EQU     3            	;Edge/level select B; any channel
ELSA      	EQU     2            	;Edge/level select A; any channel
TOV       	EQU     1            	;Toggle-on-overflow; any channel
CHMAX     	EQU     0            	;PWM 100% duty cycle; any channel


*************************************************************
* ADC - Analog to Digital Converter
*************************************************************
ADSCR     	EQU     $3C       	;A/D Status and Control
ADR       	EQU     $3D       	;A/D Data
ADCLK     	EQU	$3E       	;A/D Clock Rate

* ADSCR bits
COCO            EQU     7
AIEN            EQU     6
ADCO            EQU     5
ADCH4           EQU     4
ADCH3           EQU     3
ADCH2           EQU     2
ADCH1           EQU     1
ADCH0           EQU     0

* ADCLK bits
ADIV2           EQU     7
ADIV1           EQU     6
ADIV0           EQU     5
ADICLK          EQU     4

* A/D channel masks
* To use, load ADSCR, OR with ADMASK, AND with desired channel to
* select a channel for conversion
ADMASK    	EQU     $1F
AD0       	EQU     $E0+$00
AD1       	EQU     $E0+$01
AD2       	EQU     $E0+$02
AD3       	EQU     $E0+$03
AD4       	EQU     $E0+$04
AD5       	EQU     $E0+$05
AD6       	EQU     $E0+$06
AD7       	EQU     $E0+$07


*************************************************************
* KBI - Keyboard Interrupt Module
*************************************************************
INTKBSCR  	EQU     $1A             ;Keyboard status and control
INTKBIER  	EQU     $1B		;Keyboard interrupt enable

* INTKBSCR bits
KEYF      	EQU     3
ACKK      	EQU     2
IMASKK    	EQU     1
MODEK     	EQU 	0

* INTKBIER bits
KBIE7           EQU     7
KBIE6           EQU     6
KBIE5           EQU     5
KBIE4           EQU     4
KBIE3           EQU     3
KBIE2           EQU     2
KBIE1           EQU     1
KBIE0           EQU     0
KBIE7.          EQU     $80
KBIE6.          EQU     $40
KBIE5.          EQU     $20
KBIE4.          EQU     $10
KBIE3.          EQU     $08
KBIE2.          EQU     $04
KBIE1.          EQU     $02
KBIE0.          EQU     $01

*************************************************************
* VECTORS
*************************************************************
TBVEC           EQU     $FFDC           ;Time base vector
ADCVEC          EQU     $FFDE           ;ADC conversion complete vector
KBIVEC          EQU     $FFE0           ;Keyboard interrupt
SCITXVEC        EQU     $FFE2           ;SCI transmit
SCIRXVEC        EQU     $FFE4           ;SCI receive
SCIERVEC        EQU     $FFE6           ;SCI error
SPITXVEC        EQU     $FFE8           ;SPI transmit
SPIRXVEC        EQU     $FFEA           ;SPI receive
T2OFVEC         EQU     $FFEC           ;Timer 2 overflow
T2CH1VEC        EQU     $FFEE           ;Timer 2 channel 1
T2CH0VEC        EQU     $FFF0           ;Timer 2 channel 0
T1OFVEC         EQU     $FFF2           ;Timer 1 overflow
T1CH1VEC        EQU     $FFF4           ;Timer 1 channel 1
T1CH0VEC        EQU     $FFF6           ;Timer 1 channel 0
PLLVEC          EQU     $FFF8           ;PLL vector
IRQ1VEC         EQU     $FFFA           ;IRQ1' vector
SWIVEC          EQU     $FFFC           ;SWI vector
RESETVEC        EQU     $FFFE           ;Reset vector

*************************************************************
* MEMORY SPACE
*************************************************************
RAMSPACE        EQU     $40		;Start of user RAM
FLASHSPACE      EQU     $B000	        ;Start of user ROM (FLASH)
